# prometheus-virtual-metrics

[![PyPI - Version](https://img.shields.io/pypi/v/prometheus-virtual-metrics)](https://pypi.org/project/prometheus-virtual-metrics)
[![PyPI - License](https://img.shields.io/pypi/l/prometheus-virtual-metrics)](https://github.com/fscherf/prometheus-virtual-metrics/blob/master/LICENSE.txt)
